@@ -145,7 +145,7 @@ BAKERY_GZIP = True
 
 CSP_DEFAULT_SRC = (
     "'self'",
-    "releases.wagtail.io"
+    "releases.wagtail.io",
 )
 CSP_MANIFEST_SRC = (
     "'self'",
@@ -163,7 +163,7 @@ CSP_SCRIPT_SRC = (
     "www.googletagmanager.com",
     "'unsafe-eval'",
     "'unsafe-inline'",
-    "assets.calendly.com"
+    "assets.calendly.com",
 )
 
 CSP_FONT_SRC = (
@@ -171,7 +171,7 @@ CSP_FONT_SRC = (
     'fonts.googleapis.com',
     'fonts.gstatic.com',
     'data:',
-    'blob:'
+    'blob:',
 )
 CSP_IMG_SRC = (
     "'self'",
@@ -186,7 +186,8 @@ CSP_FRAME_SRC = (
     '*.vimeo.com',
     '*.youtube.com',
     'www.facebook.com',
-    "assets.calendly.com"
+    'assets.calendly.com',
+    'calendly.com',
 )
 
 CSP_CONNECT_SRC = (
